@@ -57,7 +57,7 @@ has tableCfg => sub {
     return [
         {
             label => trm('Id'),
-            type => 'str',
+            type => 'number',
             width => '1*',
             key => 'song_id',
             sortable => $self->true,
@@ -65,35 +65,35 @@ has tableCfg => sub {
         },
         {
             label => trm('Title'),
-            type => 'str',
+            type => 'string',
             width => '6*',
             key => 'song_title',
             sortable => $self->true,
         },
         {
             label => trm('Voices'),
-            type => 'str',
+            type => 'string',
             width => '1*',
             key => 'song_voices',
             sortable => $self->true,
         },
         {
             label => trm('Composer'),
-            type => 'str',
+            type => 'string',
             width => '2*',
             key => 'song_composer',
             sortable => $self->true,
         },
         {
             label => trm('Page'),
-            type => 'str',
+            type => 'string',
             width => '1*',
             key => 'song_page',
             sortable => $self->true,
         },
         {
             label => trm('Note'),
-            type => 'str',
+            type => 'string',
             width => '3*',
             key => 'song_note',
             sortable => $self->true,
